@@ -1,27 +1,29 @@
 #pragma once
 
+#include "location.hh"
 #include <cassert>
 #include <cstddef>
-#include "location.hh"
 #include <memory>
-#include <rumur/except.h>
 #include <rumur/Node.h>
 #include <rumur/Ptr.h>
+#include <rumur/except.h>
 #include <string>
 #include <unordered_map>
 #include <vector>
 
+#ifndef RUMUR_API
+#define RUMUR_API __attribute__((visibility("default")))
+#endif
+
 namespace rumur {
 
-class Symtab {
+class RUMUR_API Symtab {
 
- private:
+private:
   std::vector<std::unordered_map<std::string, Ptr<Node>>> scope;
 
- public:
-  void open_scope() {
-    scope.emplace_back();
-  }
+public:
+  void open_scope() { scope.emplace_back(); }
 
   void close_scope() {
     assert(!scope.empty());
@@ -32,16 +34,16 @@ class Symtab {
     assert(!scope.empty());
     if (scope.back().count(name) > 0)
       throw Error("symbol \"" + name + "\" was previously declared",
-        value->loc);
+                  value->loc);
     scope.back()[name] = value;
   }
 
-  template<typename U>
+  template <typename U>
   Ptr<U> lookup(const std::string &name, const location &loc) const {
     for (auto it = scope.rbegin(); it != scope.rend(); it++) {
       auto it2 = it->find(name);
       if (it2 != it->end()) {
-        if (auto ret = dynamic_cast<const U*>(it2->second.get())) {
+        if (auto ret = dynamic_cast<const U *>(it2->second.get())) {
           return Ptr<U>(ret->clone());
         } else {
           break;
@@ -52,4 +54,4 @@ class Symtab {
   }
 };
 
-}
+} // namespace rumur
