@@ -1,6 +1,7 @@
 #include <cstddef>
 #include <rumur/Property.h>
 #include <rumur/Ptr.h>
+#include <rumur/except.h>
 #include <rumur/traverse.h>
 
 namespace rumur {
@@ -11,6 +12,11 @@ Property::Property(Category category_, const Ptr<Expr> &expr_,
 
 Property *Property::clone() const { return new Property(*this); }
 
+void Property::validate() const {
+  if (!expr->is_boolean())
+    throw Error("properties must be boolean expressions", loc);
+}
+
 void Property::visit(BaseTraversal &visitor) { visitor.visit_property(*this); }
 
 void Property::visit(ConstBaseTraversal &visitor) const {
