@@ -1,7 +1,7 @@
 #pragma once
 
-#include <cstddef>
 #include "CodeGenerator.h"
+#include <cstddef>
 #include <iostream>
 #include <rumur/rumur.h>
 #include <string>
@@ -10,9 +10,11 @@
 #include <vector>
 
 // generator for C-like code
-class CLikeGenerator : public CodeGenerator, public rumur::ConstBaseTraversal {
+class __attribute__((visibility("hidden"))) CLikeGenerator
+    : public CodeGenerator,
+      public rumur::ConstBaseTraversal {
 
- protected:
+protected:
   std::ostream &out;
   bool pack;
 
@@ -29,14 +31,15 @@ class CLikeGenerator : public CodeGenerator, public rumur::ConstBaseTraversal {
   // whether each comment has been written to the output yet
   std::vector<bool> emitted;
 
- public:
+public:
   CLikeGenerator(const std::vector<rumur::Comment> &comments_,
-    std::ostream &out_, bool pack_): out(out_), pack(pack_),
-    comments(comments_), emitted(comments_.size(), false) { }
+                 std::ostream &out_, bool pack_)
+      : out(out_), pack(pack_), comments(comments_),
+        emitted(comments_.size(), false) {}
 
   void visit_add(const rumur::Add &n) final;
   void visit_aliasdecl(const rumur::AliasDecl &n) final;
-  void visit_aliasrule(const rumur::AliasRule&) final;
+  void visit_aliasrule(const rumur::AliasRule &) final;
   void visit_aliasstmt(const rumur::AliasStmt &n) final;
   void visit_and(const rumur::And &n) final;
   void visit_array(const rumur::Array &n) final;
@@ -54,7 +57,7 @@ class CLikeGenerator : public CodeGenerator, public rumur::ConstBaseTraversal {
   void visit_exprid(const rumur::ExprID &n) final;
   void visit_field(const rumur::Field &n) final;
   void visit_implication(const rumur::Implication &n) final;
-  void visit_isundefined(const rumur::IsUndefined&) final;
+  void visit_isundefined(const rumur::IsUndefined &) final;
   void visit_for(const rumur::For &n) final;
   void visit_forall(const rumur::Forall &n) final;
   void visit_functioncall(const rumur::FunctionCall &n) final;
@@ -74,16 +77,16 @@ class CLikeGenerator : public CodeGenerator, public rumur::ConstBaseTraversal {
   void visit_number(const rumur::Number &n) final;
   void visit_or(const rumur::Or &n) final;
   void visit_procedurecall(const rumur::ProcedureCall &n) final;
-  void visit_property(const rumur::Property&) final;
+  void visit_property(const rumur::Property &) final;
   void visit_propertystmt(const rumur::PropertyStmt &n) final;
   void visit_put(const rumur::Put &n) final;
   void visit_quantifier(const rumur::Quantifier &n) final;
-  void visit_range(const rumur::Range&) final;
+  void visit_range(const rumur::Range &) final;
   void visit_record(const rumur::Record &n) final;
   void visit_return(const rumur::Return &n) final;
   void visit_rsh(const rumur::Rsh &n) final;
-  void visit_ruleset(const rumur::Ruleset&) final;
-  void visit_scalarset(const rumur::Scalarset&) final;
+  void visit_ruleset(const rumur::Ruleset &) final;
+  void visit_scalarset(const rumur::Scalarset &) final;
   void visit_sub(const rumur::Sub &n) final;
   void visit_switch(const rumur::Switch &n) final;
   void visit_switchcase(const rumur::SwitchCase &n) final;
@@ -101,13 +104,13 @@ class CLikeGenerator : public CodeGenerator, public rumur::ConstBaseTraversal {
   // make this class abstract
   virtual ~CLikeGenerator() = 0;
 
- private:
+private:
   // generate a print statement of the given expression and (possibly
   // not-terminal) type
   void print(const std::string &suffix, const rumur::TypeExpr &t,
-    const rumur::Expr &e, size_t counter);
+             const rumur::Expr &e, size_t counter);
 
- protected:
+protected:
   // output comments preceding the given node
   size_t emit_leading_comments(const rumur::Node &n);
 
