@@ -1,9 +1,9 @@
-#include <cstddef>
-#include "CLikeGenerator.h"
 #include "generate_h.h"
-#include <iostream>
+#include "CLikeGenerator.h"
 #include "options.h"
 #include "resources.h"
+#include <cstddef>
+#include <iostream>
 #include <rumur/rumur.h>
 #include <string>
 #include <vector>
@@ -14,9 +14,10 @@ namespace {
 
 class HGenerator : public CLikeGenerator {
 
- public:
+public:
   HGenerator(const std::vector<Comment> &comments_, std::ostream &out_,
-    bool pack_): CLikeGenerator(comments_, out_, pack_) { }
+             bool pack_)
+      : CLikeGenerator(comments_, out_, pack_) {}
 
   void visit_constdecl(const ConstDecl &n) final {
     *this << indentation() << "extern const ";
@@ -81,7 +82,7 @@ class HGenerator : public CLikeGenerator {
       std::string sep;
       for (const Quantifier &q : n.quantifiers) {
         *this << sep;
-        if (auto t = dynamic_cast<const TypeExprID*>(q.type.get())) {
+        if (auto t = dynamic_cast<const TypeExprID *>(q.type.get())) {
           *this << t->name;
         } else {
           *this << value_type;
@@ -104,7 +105,7 @@ class HGenerator : public CLikeGenerator {
       std::string sep;
       for (const Quantifier &q : n.quantifiers) {
         *this << sep;
-        if (auto t = dynamic_cast<const TypeExprID*>(q.type.get())) {
+        if (auto t = dynamic_cast<const TypeExprID *>(q.type.get())) {
           *this << t->name;
         } else {
           *this << value_type;
@@ -125,7 +126,7 @@ class HGenerator : public CLikeGenerator {
       std::string sep;
       for (const Quantifier &q : n.quantifiers) {
         *this << sep;
-        if (auto t = dynamic_cast<const TypeExprID*>(q.type.get())) {
+        if (auto t = dynamic_cast<const TypeExprID *>(q.type.get())) {
           *this << t->name;
         } else {
           *this << value_type;
@@ -151,7 +152,7 @@ class HGenerator : public CLikeGenerator {
       std::string sep;
       for (const Quantifier &q : n.quantifiers) {
         *this << sep;
-        if (auto t = dynamic_cast<const TypeExprID*>(q.type.get())) {
+        if (auto t = dynamic_cast<const TypeExprID *>(q.type.get())) {
           *this << t->name;
         } else {
           *this << value_type;
@@ -177,10 +178,10 @@ class HGenerator : public CLikeGenerator {
   }
 };
 
-}
+} // namespace
 
 void generate_h(const Node &n, const std::vector<Comment> &comments, bool pack,
-    std::ostream &out) {
+                std::ostream &out) {
 
   // write the static prefix to the beginning of the source file
   for (size_t i = 0; i < resources_h_prefix_h_len; i++)
@@ -190,9 +191,8 @@ void generate_h(const Node &n, const std::vector<Comment> &comments, bool pack,
   gen.dispatch(n);
 
   // close the `extern "C"` block opened in ../resources/h_prefix.h
-  out
-    << "\n"
-    << "#ifdef __cplusplus\n"
-    << "}\n"
-    << "#endif\n";
+  out << "\n"
+      << "#ifdef __cplusplus\n"
+      << "}\n"
+      << "#endif\n";
 }
