@@ -2,6 +2,10 @@
 
 #include <cstddef>
 
+#ifdef __cplusplus
+extern "C" {
+#endif
+
 extern const unsigned char resources_includes_c[];
 extern const size_t resources_includes_c_len;
 
@@ -10,3 +14,7 @@ extern const size_t resources_header_c_len;
 
 extern const unsigned char doc_rumur_1[];
 extern const size_t doc_rumur_1_len;
+
+#ifdef __cplusplus
+}
+#endif
