@@ -1,27 +1,26 @@
-#include <cstddef>
+#include "translate.h"
 #include "../../../common/isa.h"
-#include <rumur/rumur.h>
-#include "except.h"
-#include <locale>
-#include "logic.h"
 #include "../options.h"
+#include "except.h"
+#include "logic.h"
+#include <cstddef>
+#include <locale>
+#include <rumur/rumur.h>
 #include <sstream>
 #include <string>
-#include "translate.h"
 
 using namespace rumur;
 
 namespace smt {
 
-namespace { class Translator : public ConstExprTraversal {
+namespace {
+class Translator : public ConstExprTraversal {
 
- private:
+private:
   std::ostringstream buffer;
 
- public:
-  std::string str() const {
-    return buffer.str();
-  }
+public:
+  std::string str() const { return buffer.str(); }
 
   Translator &operator<<(const std::string &s) {
     buffer << s;
@@ -92,9 +91,7 @@ namespace { class Translator : public ConstExprTraversal {
     translate_quantified(n.quantifier, *n.expr, true);
   }
 
-  void visit_functioncall(const FunctionCall &n) {
-    throw Unsupported(n);
-  }
+  void visit_functioncall(const FunctionCall &n) { throw Unsupported(n); }
 
   void visit_geq(const Geq &n) {
     *this << "(" << geq() << " " << *n.lhs << " " << *n.rhs << ")";
@@ -108,9 +105,7 @@ namespace { class Translator : public ConstExprTraversal {
     *this << "(=> " << *n.lhs << " " << *n.rhs << ")";
   }
 
-  void visit_isundefined(const IsUndefined &n) {
-    throw Unsupported(n);
-  }
+  void visit_isundefined(const IsUndefined &n) { throw Unsupported(n); }
 
   void visit_leq(const Leq &n) {
     *this << "(" << leq() << " " << *n.lhs << " " << *n.rhs << ")";
@@ -140,13 +135,9 @@ namespace { class Translator : public ConstExprTraversal {
     *this << "(not (= " << *n.lhs << " " << *n.rhs << "))";
   }
 
-  void visit_number(const Number &n) {
-    *this << numeric_literal(n.value);
-  }
+  void visit_number(const Number &n) { *this << numeric_literal(n.value); }
 
-  void visit_not(const Not &n) {
-    *this << "(not " << *n.rhs << ")";
-  }
+  void visit_not(const Not &n) { *this << "(not " << *n.rhs << ")"; }
 
   void visit_or(const Or &n) {
     *this << "(or " << *n.lhs << " " << *n.rhs << ")";
@@ -168,7 +159,7 @@ namespace { class Translator : public ConstExprTraversal {
     *this << "(" << bxor() << " " << *n.lhs << " " << *n.rhs << ")";
   }
 
- private:
+private:
   void translate_quantified(const Quantifier &q, const Expr &e, bool forall) {
 
     // find a name for the quantified variable
@@ -196,15 +187,15 @@ namespace { class Translator : public ConstExprTraversal {
       if (isa<Enum>(t) || isa<Scalarset>(t)) {
         *this << numeric_literal(0);
       } else {
-        assert(isa<Range>(t) && "non-(range|enum|scalarset) variable in "
-          "quantifier");
-        const Range &r = dynamic_cast<const Range&>(*t);
+        assert(isa<Range>(t) &&
+               "non-(range|enum|scalarset) variable in quantifier");
+        const Range &r = dynamic_cast<const Range &>(*t);
         assert(r.min != nullptr && "unbounded range type");
         *this << *r.min;
       }
     } else {
-      assert(q.from != nullptr && "quantified variable has no type and also no "
-        "lower bound");
+      assert(q.from != nullptr &&
+             "quantified variable has no type and also no lower bound");
       *this << *q.from;
     }
     *this << ")";
@@ -214,41 +205,41 @@ namespace { class Translator : public ConstExprTraversal {
     if (q.type != nullptr) {
       const Ptr<TypeExpr> t = q.type->resolve();
 
-      assert ((isa<Enum>(t) || isa<Range>(t) || isa<Scalarset>(t)) &&
-        "non-(range|enum|scalarset) variable in quantifier");
+      assert((isa<Enum>(t) || isa<Range>(t) || isa<Scalarset>(t)) &&
+             "non-(range|enum|scalarset) variable in quantifier");
 
-      if (auto n = dynamic_cast<const Enum*>(t.get())) {
+      if (auto n = dynamic_cast<const Enum *>(t.get())) {
         size_t s = n->members.size();
         *this << ub_rel2 << " " << qname << " " << numeric_literal(s);
 
-      } else if (auto r = dynamic_cast<const Range*>(t.get())) {
-        assert (r->max != nullptr && "unbounded range type");
+      } else if (auto r = dynamic_cast<const Range *>(t.get())) {
+        assert(r->max != nullptr && "unbounded range type");
         *this << ub_rel1 << " " << qname << " " << *r->max;
 
       } else {
-        auto s = dynamic_cast<const Scalarset&>(*t);
+        auto s = dynamic_cast<const Scalarset &>(*t);
         *this << ub_rel2 << " " << qname << " " << *s.bound;
       }
     } else {
-      assert(q.to != nullptr && "quantified variable has no type and also no "
-        "upper bound");
+      assert(q.to != nullptr &&
+             "quantified variable has no type and also no upper bound");
       *this << ub_rel1 << " " << qname << " " << *q.to;
     }
     *this << ")";
 
     // or/and “!∃i. q = lb + i * step”/“∃i. q = lb + i * step”
     const std::string iname = qname + "_iteration";
-    *this << " " << step_o << "(exists ((" << iname << " " << qtype << ")) (= "
-      << qname << " (" << add() << " ";
+    *this << " " << step_o << "(exists ((" << iname << " " << qtype
+          << ")) (= " << qname << " (" << add() << " ";
     if (q.type != nullptr) {
       const Ptr<TypeExpr> t = q.type->resolve();
 
       if (isa<Enum>(t) || isa<Scalarset>(t)) {
         *this << numeric_literal(0);
       } else {
-        assert(isa<Range>(t) && "non-(range|enum|scalarset) variable in "
-          "quantifier");
-        const Range &r = dynamic_cast<const Range&>(*t);
+        assert(isa<Range>(t) &&
+               "non-(range|enum|scalarset) variable in quantifier");
+        const Range &r = dynamic_cast<const Range &>(*t);
         assert(r.min != nullptr && "unbounded range type");
         *this << *r.min;
       }
@@ -266,8 +257,8 @@ namespace { class Translator : public ConstExprTraversal {
     // finally the enclosed expression itself
     *this << " " << e << "))";
   }
-
-}; }
+};
+} // namespace
 
 std::string translate(const Expr &expr) {
   Translator t;
@@ -302,4 +293,4 @@ std::string mangle(const std::string &s, size_t id) {
   return prefix + "s" + std::to_string(id);
 }
 
-}
+} // namespace smt
