@@ -1,4 +1,4 @@
--- checker_output: None if self.xml else re.compile(r'^\s*cover "x was true" hit 1 times$', re.MULTILINE)
+-- checker_output: None if xml else re.compile(r'^\s*cover "x was true" hit 1 times$', re.MULTILINE)
 
 -- Test a cover property used as a statement
 
