@@ -1,6 +1,6 @@
 -- rumur_flags: ['--threads', '1', '--max-errors', '2']
 -- checker_exit_code: 1
--- checker_output: None if self.xml else re.compile(r'^Startstate 1 fired\.\nx:0\n----------\n\nRule "foo" fired\.\nx:1\n----------\n\nEnd of the error trace\.(.|\n)*^Startstate 1 fired\.\nx:0\n----------\n\nRule "bar" fired\.\nx:2\n----------\n\nEnd of the error trace\.', re.MULTILINE)
+-- checker_output: None if xml else re.compile(r'^Startstate 1 fired\.\nx:0\n----------\n\nRule "foo" fired\.\nx:1\n----------\n\nEnd of the error trace\.(.|\n)*^Startstate 1 fired\.\nx:0\n----------\n\nRule "bar" fired\.\nx:2\n----------\n\nEnd of the error trace\.', re.MULTILINE)
 
 /* This model is designed to trigger a bug that was observed on commit
  * 0f66cb1de6e4eb359fc4aa1ab4d55c8dd951a04d. When attempting to report multiple
